*****
Usage
*****

Settings, information and tasks relating to purchases can be found under the
[:menuselection:`Purchase`] main menu item.

.. include:: prepurchase.inc.rst
.. include:: process.inc.rst
.. include:: returns.inc.rst
